@@ -12,7 +12,7 @@ use Tags::HTML::Messages;
 
 Readonly::Array our @FORM_METHODS => qw(post get);
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -20,7 +20,8 @@ sub new {
 
 	# Create object.
 	my ($object_params_ar, $other_params_ar) = split_params(
-		['css_access', 'form_method', 'lang', 'register_url', 'text', 'width'], @params);
+		['css_access', 'form_method', 'lang', 'logo_image_url', 'register_url',
+		'text', 'width'], @params);
 	my $self = $class->SUPER::new(@{$other_params_ar});
 
 	# CSS style for access box.
@@ -32,6 +33,9 @@ sub new {
 	# Language.
 	$self->{'lang'} = 'eng';
 
+	# Logo.
+	$self->{'logo_image_url'} = undef;
+
 	# Register URL.
 	$self->{'register_url'} = undef;
 
@@ -87,7 +91,6 @@ sub _process {
 	my $username_id = 'username';
 	my $password_id = 'password';
 
-	# Main content.
 	$self->{'tags'}->put(
 		['b', 'form'],
 		['a', 'class', $self->{'css_access'}],
@@ -97,6 +100,21 @@ sub _process {
 		['b', 'legend'],
 		['d', $self->_text('login')],
 		['e', 'legend'],
+	);
+
+	if (defined $self->{'logo_image_url'}) {
+		$self->{'tags'}->put(
+			['b', 'div'],
+			['a', 'class', 'logo'],
+			['b', 'img'],
+			['a', 'src', $self->{'logo_image_url'}],
+			['a', 'alt', 'logo'],
+			['e', 'img'],
+			['e', 'div'],
+		);
+	}
+
+	$self->{'tags'}->put(
 
 		['b', 'p'],
 		['b', 'label'],
@@ -164,6 +182,18 @@ sub _process_css {
 		['d', 'box-shadow', '0 0 10px rgba(0, 0, 0, 0.2)'],
 		['e'],
 
+		['s', '.'.$self->{'css_access'}.' .logo'],
+		['d', 'height', '5em'],
+		['d', 'width', '100%'],
+		['e'],
+
+		['s', '.'.$self->{'css_access'}.' img'],
+		['d', 'margin', 'auto'],
+		['d', 'display', 'block'],
+		['d', 'max-width', '100%'],
+		['d', 'max-height', '5em'],
+		['e'],
+
 		['s', '.'.$self->{'css_access'}.' fieldset'],
 		['d', 'border', 'none'],
 		['d', 'padding', 0],
@@ -245,8 +275,8 @@ Tags::HTML::Login::Access - Tags helper for login access.
  use Tags::HTML::Login::Access;
 
  my $obj = Tags::HTML::Login::Access->new(%params);
- $obj->process;
- $obj->process_css;
+ $obj->process($message_ar);
+ $obj->process_css($message_types_hr);
 
 =head1 METHODS
 
@@ -286,6 +316,12 @@ Language in ISO 639-3 code.
 
 Default value is 'eng'.
 
+=item * C<logo_image_url>
+
+URL to logo image.
+
+Default value is undef.
+
 =item * C<register_url>
 
 URL to registration page.
@@ -320,18 +356,24 @@ Default value is:
 
 =head2 C<process>
 
- $obj->process;
+ $obj->process($message_ar);
 
 Process Tags structure for login box.
 
+Reference to array with message objects C<$message_ar> must be a instance of
+L<Data::Message::Simple> object.
+
 Returns undef.
 
 =head2 C<process_css>
 
- $obj->process_css;
+ $obj->process_css($message_types_hr);
 
 Process CSS::Struct structure for login box.
 
+Variable C<$message_type_hr> is reference to hash with keys for message type and value for color in CSS style.
+Possible message types are info and error now. Types are defined in L<Data::Message::Simple>.
+
 Returns undef.
 
 =head1 ERRORS
@@ -508,6 +550,10 @@ L<Tags::HTML::Messages>.
 
 Tags helper for login button.
 
+=item L<Tags::HTML::Login::Register>
+
+Tags helper for login register.
+
 =back
 
 =head1 REPOSITORY
@@ -522,12 +568,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2021-2023
+© 2021-2023 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
